// java

package edu.washington.cac.calendar;

import javax.servlet.http.HttpServletRequest;

import edu.washington.cac.calendar.data.User;

/**
  An object that will 'authenticate' a user by reading the user's name
  from an HTTP GET parameter.

  This is useful for testing, but clearly not a secure method of 
  authentication.  Therefore, this object will only authenticate if
  the Calendar property allowInsecureLogin is true.

  @author Greg Barnes
  @version 1.0
  @see CalProperties
 */
public class InsecureAuthenticator
{
  /** 
    @return The user indicated by the servlet request
    @param req The HTTP servlet request object
    @exception IllegalStateException If insecure logins are not allowed
   */
  public User getUser(HttpServletRequest req) throws IllegalStateException
  {
    if (CalProperties.allowInsecureLogin()) {
      return new User(req.getParameter("uid"));
    } else {
      throw new IllegalStateException("Insecure logins are not allowed.");
    }
  }
}
