// Java

package edu.washington.cac.fanglin.util;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.InputStreamReader;
import java.io.InterruptedIOException;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import java.net.Socket;
import java.util.List;

/**  Object that establishes a socket connection to a server and 
     performs two-way data exchange.

     @author Fang Lin
     @version 1.1
 */
public class SocketClient {
  public static final String CN = "SocketClient:: ";
  public static final int TIMEOUT = 20000;

  protected Socket socket = null;
  protected BufferedReader in= null;		
  protected PrintWriter out= null;
  protected String host = null;
  protected int port;
  protected int timeout = TIMEOUT;
  public SocketClient (String host, int port) 
    {
      if (host == null){
	throw new IllegalArgumentException (CN + "invalid host name");
      }
      if (port<=0) {
	throw new IllegalArgumentException (CN + "invalid port number");
      }
      this.host = host;
      this.port = port;
    }
  
  public void talk (String dataToWrite,
		    List results)
    throws IOException {

      try {
	connect();
	setupIO();

	out.println(dataToWrite);
	out.flush();
	
	getResult(results);
	
      } catch (IOException e) {
	if (e.getMessage()!=null)
	  System.err.println(CN + dataToWrite + " -> " +e.getMessage());
	throw new IOException();
      } finally {
	closeSocket();
      }
    }

  public void setTimeOut (int time)
    {
      timeout = time;
    }

  /** @return Vector of String.
   */
  protected void getResult(List resultSet)
    throws IOException  {

    try {
      if (timeout > 0) {
	socket.setSoTimeout(timeout);
      }
      String result = in.readLine();
      while (result != null) {
	resultSet.add (result.trim());
	result = in.readLine();
      }

    } catch (InterruptedIOException e) {  // timeout on socket read    
      throw new IOException ("read time out.");
    }
  }
  
  protected void connect() 
    throws IOException {

    // System.err.println(CN + host + port);
    socket = new Socket(host, port);
    /*
    try {
      System.err.println(CN + host + port);
      socket = new Socket(host,port);
    } catch (IOException e) {
    }
    if (socket==null) {
      InetAddress[] ia;

      try {
	ia = InetAddress.getAllByName(host);
      } catch (UnknownHostException e) {
	throw new IOException("Cannot resolve hostname: " + host);
      }

      for (int i = 0; i < ia.length; i++) {
	try {
	  socket = new Socket(ia[i], port);
	} catch (ConnectException e) {
	  //keep trying others 
	}
	if (socket != null) {
	  break;
	}
      }
      if (socket==null) {
	throw new IOException("Give up trying connect to " + host);
      }
    }
    */
  }
    
  protected void setupIO() 
    throws IOException  {
    in = new BufferedReader(new InputStreamReader(socket.getInputStream()));

    out = new PrintWriter
      (new BufferedWriter(new OutputStreamWriter(socket.getOutputStream())),
       true);
  }

  protected void closeSocket() 
    throws IOException {
    //out.close();
    //in.close();
    if (socket!=null)
      socket.close();
  }
}
