// Java

package edu.washington.cac.myuw.servlet;

import java.io.PrintStream;

  /** An object that creates Log objects

    @author Greg Barnes
    @version 1.0
  */
public class LogFactory {
  private String defaultUid;
  private PrintStream defaultPrintStream;

  /**
    Create a new factory, using default values
   */
  public LogFactory() {
    this(null, null);   // Log fills in default values for null 
  }
    
  /**
    Create a new factory
    @param defaultUid The default uid for the logs the factory will create
    @param defaultPrintStream The default <code>java.io.PrintStream</code>
      for the logs the factory will create
   */
  public LogFactory(String defaultUid, PrintStream defaultPrintStream) {
    this.defaultUid = defaultUid;
    this.defaultPrintStream = defaultPrintStream;
  }
    
  /**
    @return a new log using the defaults
   */
  public Log create() {
    return new Log(this.defaultUid, this.defaultPrintStream);
  }

  /**
    @return a new log using the default PrintStream
   */
  public Log create(String uid) {
    return new Log(uid, this.defaultPrintStream);
  }

  /**
    @return a new log 
   */
  public Log create(String uid, PrintStream printStream) {
    return new Log(uid, printStream);
  }
}
