package pubevents.authtable;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.db.Fields;
// import edu.washington.cac.calendar.db.Tables;

import pubevents.AdminServlet;
import pubevents.PEDefaults;
import pubevents.PEParameter;
import pubevents.addevents.SqlStatements;
import pubevents.util.ConvertRoutines;
import pubevents.util.PrintErrorMessage;
import pubevents.util.PrintWebPage;

import uwcal.out.Page;

/** Edit userid for no null and less than or equal to 8 characters and
               then add it to authorization table if no error. 
  
  @author Leman Chung
  @version 2.0
 */
public class AddUsersEdit extends AdminServlet 
{
  public void performAction(HttpServletRequest req, HttpServletResponse res)
                 throws IOException
  {
    int userid = 0;
    ResultSet rs = null;
    String templateFile = PEDefaults.ADD_USERS;
    String error_msg = "";
    SqlStatements sqlstmts;

    ConvertRoutines convRoutine;

    PEParameter pep = new PEParameter(req);
    PrintWriter out = res.getWriter();
    int counter = 0;

    String html_title = "Events Calendar: Add A User to Authorization Table.";

    if (pep.getUserid() == null) {
        error_msg = "Missing User's NetID!";
    } else if (pep.getUserid().length() > 8) {
        error_msg = "User's NetID can not be longer than 8 characters!";
    } else if (pep.getUserid().indexOf(" ") != -1) {
        error_msg = "Found space inside user's NetID!";
    } else if (pep.getUserid().indexOf(",") != -1) {
        error_msg = "Found comma inside user's NetID!";
    }

    if (error_msg == "") {
        sqlstmts = new SqlStatements();
        try {
             rs = sqlstmts.selectUsers(pep.getUserid());
             if (rs.next()) {
                  // existed, and then retrieve userid.
                userid = rs.getInt(Fields.UUSER_ID.getName());
             } else {
                  // not exist, add it to users table.
                userid = sqlstmts.addUsers(pep.getUserid());
             }
             rs.close();
             rs = sqlstmts.selectAuth(userid);
             if (rs.next()) {  // print user already existed error message.
                 error_msg = "User " + pep.getUserid() + " already existed in authorization table.&nbsp;&nbsp;If you are trying to update usertype, please delete it first and then re-add it back to authorization table.";
             }
        } catch (SQLException e) {
            e.printStackTrace(System.err);
            System.err.println("SQL Exception: " + e.getMessage());
            error_msg = "ERROR: " + e.getMessage();
        } catch (Exception e) {
            e.printStackTrace(System.err);
            System.err.println("Exception: " + e.getMessage());
            error_msg = "ERROR: " + e.getMessage();
        } finally {
          sqlstmts.close();
        }
    }

    if (error_msg != "") {
          // print error_msg
        convRoutine = new ConvertRoutines();
        BufferedReader in = new BufferedReader(new InputStreamReader(
                this.getClass().getResourceAsStream(templateFile)));

        String field;
        String aline = in.readLine(); // IOException
        while (aline != null) {
          if (aline.startsWith("%%%html_title")) {
              out.println(html_title);
          } else if (aline.startsWith("%%%logo")) {
              out.println(Page.LOGO);
          } else if (aline.startsWith("%%%error_msg")) {
              new PrintErrorMessage().printError(out, error_msg);
          } else if (aline.startsWith("%%%userid")) {
	      if (pep.getUserid() == null) {
		out.println("");
	      } else {
                out.println("\"" + pep.getUserid() + "\"");
              }
          } else if (aline.startsWith("%%%checked_R")) {
              if (pep.getUsertype().equals("R")) { 
                  out.println("checked");
              }
          } else if (aline.startsWith("%%%checked_A")) {
              if (pep.getUsertype().equals("A")) { 
                  out.println("checked");
              }
          } else if (aline.startsWith("%%%")) {
              field = aline.substring(3);
              if (req.getParameter(field) != null) {
                  out.print("\"" + convRoutine.convertString(req.getParameter(field), "\"", "&quot;") + "\"");
                  // out.print("\"" + req.getParameter(field) + "\"");
              }
          } else {
              out.println(aline);
          }
          aline = in.readLine();
        }
        in.close();
    } else {
            // add the user to authorization table.
        try {
             new AddUsersAdd(req, res, userid);
        } catch (SQLException e ) {
             System.err.println(e.toString());
             throw new IOException(e.toString());
             // print error message over here to output screen
        }
    } 
    out.close();
  }
}
