package pubevents.delalerts;

import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.db.Fields;
import edu.washington.cac.calendar.db.Tables;

import pubevents.AdminServlet;
import pubevents.PEDefaults;
import pubevents.PEParameter;
import pubevents.addevents.SqlStatements;
import pubevents.updtalerts.UpdtAlerts;
import pubevents.util.AlertSocketClient;
import pubevents.util.PrintErrorMessage;
import pubevents.util.PrintWebPage;

/** DelAlerts: delete selected alerts from database.
  
  @author Leman Chung
  @version 2.0
 */
public class DelAlerts extends AdminServlet 
{
  /**
    Get SQL to delete an alert
    @param eventid id of the alert
    @return SQL to delete an alert
   */
  private static String deleteAlert(int eventid)
  {
    return "delete from " + Tables.EVENTS + " where " +
           Fields.EEVENT_ID.getInsertName() + "=" + eventid;
  }

  /**
    Get SQL to delete an alert's entries in the event_keywords tables
    @param eventid id of the alert
    @return SQL to delete an alert's entries in the event_keywords tables
   */
  private static String deleteAlertEK(int eventid)
  {
    return "delete from " + Tables.EVENTKEYWORDS + " where " +
           Fields.EKEVENT_ID.getInsertName() + "=" + eventid;
  }

  public void performAction(HttpServletRequest req, HttpServletResponse res)
      throws IOException 
  {
    String templateBackToMenu = PEDefaults.BACK_TO_ADMIN_MENU;
    ResultSet rs = null;

    int counter = 0;
    String error_msg = "";
    
    PEParameter pep = new PEParameter(req);
    PrintWriter out = res.getWriter();

    try {
      int[] values= pep.getEventIds();
  
      if (values == null) {
        out.println("<br><br><b>No alerts have been selected to delete.</b>");
        new PrintWebPage(templateBackToMenu, out);
        return;
      }
    
      SqlStatements sqlstmts = new SqlStatements ();
  
      try {
        for (int i=0; i < values.length; i++) {
          int eventid = values[i];
  
          // delete alerts:
          // delete it from events and event_keywords table.
          try {
            rs = sqlstmts.executeQuery("select * from "
                                       + Tables.EVENTS.getName() + " where " 
                                       + Fields.EEVENT_ID.getStmtName() 
                                       + "=" + eventid);
            if (!rs.next()) {
              // deleted already
              continue;
            }
  
            sqlstmts.executeUpdate(deleteAlert(eventid));
            counter++;
   
            sqlstmts.executeUpdate(deleteAlertEK(eventid));
            sqlstmts.executeUpdate(UpdtAlerts.deleteRedalert(eventid));
          } catch (Exception e) {
            e.printStackTrace(System.err);
            System.err.println(e.getMessage());
            error_msg += "<br>" + e.getMessage();
            continue;
          }
        }
      } finally {
        sqlstmts.close();
      }
  
      if (counter > 0) {
        if (counter > 1) {
          out.println("<br><br><b>" + counter + 
                      " alerts have been deleted.</b>");
        } else {
          out.println("<br><br><b>" + counter + " alert has been deleted.</b>");
        }

        try {            // update dynamic contents and alerts.html page
          new AlertSocketClient().talk();
        } catch (Exception e) {
          e.printStackTrace(System.err);
          error_msg += " " + e.toString();
        }
      } else {
        out.println("<br><br><b>" + " No alerts have been deleted.</b>");
      }

      if (error_msg != "") {
        out.println("<br><br>");
        new PrintErrorMessage().printError(out, "ERROR: " + error_msg);
      }

      new PrintWebPage(templateBackToMenu, out);
    } finally {
      out.close();
    }
  }

  /** 
    Print out SQL used above
    @param args ignored
   */
  public static void main(String[] args)
  {
    System.out.println(deleteAlert(75));
    System.out.println(deleteAlertEK(75));
  }
}
