package pubevents.delevents;

import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.db.Fields;
import edu.washington.cac.calendar.db.Tables;

import pubevents.AdminServlet;
import pubevents.PEDefaults;
import pubevents.PEParameter;
import pubevents.addevents.SqlStatements;
import pubevents.util.PrintErrorMessage;
import pubevents.util.PrintWebPage;

/** delete other people's events.
  
  @author Leman Chung
  @version 2.1
 */
public class AdminDelEvents extends AdminServlet 
{
  /** 
    Get SQL to remove an event from the markedevents table
    @param eventid Id of the event
    @return SQL to remove an event from the markedevents table
   */
  static String deleteMarkedEvents(int eventid)
  {
    return "delete from " + Tables.MARKEDEVENTS + " where " +
           Fields.EEVENT_ID.getInsertName() + "=" + eventid;
  }

  /** 
    Get SQL to remove a sponsor
    @param sponsorid Id of the sponsor
    @param creator Creator of the sponsor
    @return SQL to remove a sponsor
   */
  public static String deleteSponsor(int sponsorid, String creator)
  {
    return "delete from " + Tables.SPONSORS + " where " +
           Fields.SSPONSOR_ID.getInsertName() + "=" + sponsorid + " and " +
           Fields.SCREATOR.getInsertName() + "=\'" + creator + "\'";
  }

  /** 
    Get SQL to remove a location
    @param locationid Id of the location
    @param creator Creator of the location
    @return SQL to remove a location
   */
  public static String deleteLocation(int locationid, String creator)
  {
    return "delete from " + Tables.LOCATIONS + " where " +
           Fields.LLOCATION_ID.getInsertName() + "=" + locationid + " and " +
           Fields.LCREATOR.getInsertName() + "=\'" + creator + "\'";
  }

  public void performAction(HttpServletRequest req, HttpServletResponse res)
      throws IOException 
  {
    String templateBackToMenu = PEDefaults.BACK_TO_ADMIN_MENU;

    PEParameter pep = new PEParameter(req);
    PrintWriter out = res.getWriter();
    
    try {
      int[] values= pep.getEventIds();
  
      if (values == null) {
        out.println("<br><br><b>No event has been selected to delete.</b>");
        new PrintWebPage(templateBackToMenu, out);
        out.close();
        return;
      }
  
      SqlStatements sqlstmts = new SqlStatements ();
      String error_msg = "";
      int counter = 0;
  
      try {
        for (int i=0; i < values.length; i++) {
          int eventid = values[i];
          String creator;
          int sponsorid, locationid;

          // delete events:
          // retrieve an event and save its sponsorid and locationid
          // and then delete it from event and event_keywords table.
          // delet sponsor and location also if no longer link to any event.

          ResultSet rs = sqlstmts.selectEvents(eventid);
     
          if (rs.next()) {
            sponsorid = rs.getInt(Fields.ESPONSOR_ID.getName());
            locationid = rs.getInt(Fields.ELOCATION_ID.getName());
            creator = rs.getString(Fields.ECREATOR.getName());
            counter++;
          } else if (counter == 0) {
            out.println("<br><br><b>Event has been deleted already!</b>");
            new PrintWebPage(templateBackToMenu, out);
            out.close();
            return;
          } else {
            continue;
          }
 
          sqlstmts.deleteEvents(eventid);
          sqlstmts.deleteEventKeywords(eventid);
          sqlstmts.executeUpdate(deleteMarkedEvents(eventid));
 
          // if sponsorid is no longer existed in events table then
          // delete this sponsor.
          rs = sqlstmts.selectSponsorFromEvents(sponsorid);

          if (!rs.next()) {
            if (sponsorid > 2) {
              sqlstmts.executeUpdate(deleteSponsor(sponsorid, creator));
            }
          }

          // if locationid is no longer existed in events table then
          // delete this location also.
          rs = sqlstmts.selectLocFromEvents(locationid);

          if (!rs.next()) {
            if (locationid > 2) {
              sqlstmts.executeUpdate(deleteLocation(locationid, creator));
            }
          }
        } // end of for loop
      } catch (Exception e) {
          e.printStackTrace(System.err);
          System.err.println(e.getMessage());
          error_msg = e.getMessage(); 
      } finally {
        sqlstmts.close();
      }

      if (error_msg == "") {
        if (counter > 1) {
          out.println("<br><br><b>" + counter + 
                      " events have been deleted.</b>");
        } else {
          out.println("<br><br><b>" + counter + " event has been deleted.</b>");
        }
      } else {
        new PrintErrorMessage().printError(out, "ERROR: " + error_msg);
      }
  
      new PrintWebPage(templateBackToMenu, out);
    } finally {
      out.close();
    }
  }

  /**
    Print out SQL statements used in this class
    @param args ignored
   */
  public static void main(String[] args)
  {
    System.out.println(deleteMarkedEvents(75));
    System.out.println(deleteSponsor(75, "fred"));
    System.out.println(deleteLocation(75, "fred"));
  }
}
