package pubevents.delevents;

import java.io.IOException;
import java.io.PrintWriter;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.calendar.db.Fields;
import pubevents.NotAdminServlet;
import pubevents.PEDefaults;
import pubevents.PEParameter;
import pubevents.addevents.SqlStatements;
import pubevents.util.PrintErrorMessage;
import pubevents.util.PrintWebPage;

/** 
  delete selected events from database.
  
  @author Leman Chung
  @version 2.1
 */
public class DeleteEvents extends NotAdminServlet 
{
  public void performAction(HttpServletRequest req, HttpServletResponse res)
      throws IOException 
  {
    String templateBackToMenu = PEDefaults.BACK_TO_MENU;

    PEParameter pep = new PEParameter(req);
    PrintWriter out = res.getWriter();
    
    int[] values= pep.getEventIds();

    if (values == null) {
      new PrintWebPage(PEDefaults.LOGOHEADER, out);
      out.println("<br><b>No event has been selected to delete.</b>");
      new PrintWebPage(templateBackToMenu, out);
      out.close();
      return;
    }

    SqlStatements sqlstmts = new SqlStatements ();
    int counter = 0;

    try {
      int sponsorid, locationid;
  
      for (int i=0; i < values.length; i++) {
        int eventid = values[i];

        // delete events:
        // retrieve an event and save its sponsorid and locationid
        // and then delete it from event and event_keywords table.
        // delet sponsor and location also if no longer link to any event.

        ResultSet rs = sqlstmts.selectEvents(eventid);
        // ResultSet rs = sqlstmts.selectEvents(eventid, getUid());
  
        if (rs.next()) {
          if (rs.getString(Fields.ECREATOR.getName()).equals(getUid())) {
              sponsorid = rs.getInt(Fields.ESPONSOR_ID.getName());
              locationid = rs.getInt(Fields.ELOCATION_ID.getName());
              counter++;
          } else {
              continue;
          }
        } else {
          continue;
        }

        sqlstmts.deleteEvents(eventid);
        sqlstmts.deleteEventKeywords(eventid);
        sqlstmts.executeUpdate(AdminDelEvents.deleteMarkedEvents(eventid));

        // if sponsorid no longer exists in events table then
        // delete this sponsor.
        rs = sqlstmts.selectSponsorFromEvents(sponsorid);

        if (!rs.next()) {
          if (sponsorid > 2) {   // keep sponsorid=0,1,2
            sqlstmts.executeUpdate(AdminDelEvents.deleteSponsor(sponsorid,
                                                                getUid()));
          }
        }

        // if locationid no longer exists in events table then
        // delete this location also.
        rs = sqlstmts.selectLocFromEvents(locationid);

        if (!rs.next()) {
          if (locationid > 2) {   // keep locationid=0,1,2
            sqlstmts.executeUpdate(AdminDelEvents.deleteLocation(locationid, 
                                                                 getUid()));
          }
        }
      }  // end of for loop.

      new PrintWebPage(PEDefaults.LOGOHEADER, out);

      if (counter > 1) {
        out.println("<br><br><b>" + counter + " events have been deleted.</b>");
      } else if (counter == 1) {
        out.println("<br><br><b>" + counter + " event has been deleted.</b>");
      } else {
        out.println("<br><br><b>Event not found or has been deleted already!</b>");
      }
    } catch (Exception e) {
      e.printStackTrace(System.err);
      System.err.println(e.getMessage());
      new PrintErrorMessage().printError(out, "ERROR: " + e.getMessage()); 
    } finally {
      sqlstmts.close();
    }

    new PrintWebPage(templateBackToMenu, out);
    out.close();
  }
}
