package pubevents.newsroom;

import java.io.BufferedOutputStream;
import java.io.FileOutputStream;
import java.io.PrintWriter;
import java.io.IOException;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.db.DBResources;
import edu.washington.cac.calendar.db.WhereClauses;

import pubevents.addevents.EventData;
import pubevents.util.ConvertRoutines;

/** Object to create HTML to summarize and give full details on alerts
  
  @author Leman Chung, Greg Barnes
  @version 2.0
  */
public class ExtractAlerts 
{
  /** Hook to the database */
  private EventData ed;

  /** @return a new hook to the database */
  private EventData newEventData() {
    return new EventData(DBResources.defaultDb());
  }
    

  /** Open a file as an output stream
    @param fileName file to open
    @return The opened stream
    @exception IOException If there's trouble
   */
  private PrintWriter getOutputFile(String fileName) throws IOException
  {
    return new PrintWriter(new BufferedOutputStream(
        new FileOutputStream(fileName)));
  }

  /** @return a <code>ResultSet</code> containing the interesting alerts
    @exception SQLException If there's a problem with the database
   */
  private ResultSet getResultSet() throws SQLException 
  {
    ed = newEventData();
    String currentDate = 
        WhereClauses.convertDate(new MyCalendar().getDateDigits());
    String qry_statement = "select events.eventid, lastmod, shortdesc, events.longdesc, events.longdesc1, link from events, event_keywords, keywords where events.eventid=event_keywords.eventid and event_keywords.keywordid=keywords.keywordid and events.publicf=\'T\' and events.startdate <= \'" + currentDate + "\' and events.enddate >= \'" + currentDate + "\' and keywords.word=\'Alerts\' and keywords.creator=\'" 
        + DBResources.adminKeywordCreator() + "\' order by events.lastmod DESC";
    return ed.executeQuery(qry_statement);
  }

  /** beginning of a query to the redalerts table */
  private static final String RED_ALERT_PRE = 
    "select * from redalerts where eventid=";

//%%%% really now, this info should be grabbed in the first query

  /** @return Is the next event a red alert?
    @param rs <code>ResultSet</code> containing the event
    @exception SQLException If there's a problem with the database
   */
  private boolean isRedAlert(ResultSet rs) throws SQLException
  {
    EventData e = newEventData();

    try {
      return e.executeQuery(RED_ALERT_PRE + rs.getString("eventid")).next();
    } finally {
      e.close();
    }
  }

  /** @return the last mod date, as a String
    @param rs ResultSet containing the last mod date
    @exception SQLException If there's a problem getting the data
   */
  private String lastModString(ResultSet rs) throws SQLException
  {
    Calendar c = Calendar.getInstance();
    c.setTime(new Date(rs.getTimestamp("lastmod").getTime()));
    return new SimpleDateFormat("MMM dd, yyyy hh:mm aa").format(c.getTime());
  }

  /** Create HTML for the box summarizing alerts
    @exception IOException If there's trouble writing the info to a file
    @exception SQLException If there's trouble getting the data from the db
   */
  private void createAlertBox() throws IOException, SQLException
  {
    PrintWriter out = getOutputFile("alert1");

    try {
      ResultSet rs = getResultSet();
      int count;

      for (count = 0; rs.next() && count < 5; count++) {
        if (count == 0) {
          out.println("<span class=\"date\">");
          out.println("Last Updated: " + lastModString(rs) + " PT");
          out.println("</span><br>");
        }

        if (isRedAlert(rs)) {
          out.print(
              "<strong><font color=\"#FF0000\" size=\"-1\">*Alert* </font>");
          out.print(rs.getString("shortdesc"));
          out.println("</strong>");
        } else if (count == 0) {
          out.println("<strong>" + rs.getString("shortdesc") + "</strong>");
        } else {
          out.println(rs.getString("shortdesc"));
        }

        out.println("<br>");
      }

      if (count > 0) {
        out.print("<a href=\"/alerts.html\">");
        out.println("Details and more alert headlines</a><br>");
      } else {
        out.println("no alerts.<br>");
      }

    } finally {
      out.close();
      ed.close();
    }
  }

  /** Create HTML for the page with full alert details

    @exception IOException If there's trouble writing the info to a file
    @exception SQLException If there's trouble getting the data from the db
   */
  private void createAlertPage() throws IOException, SQLException
  {
    PrintWriter out = getOutputFile("alerts.html");

    try {
      int count;
      ResultSet rs = getResultSet();

      out.println("<html>\n<head>");
      out.println("<title>More Details and Alerts</title></head>\n<body>");

      for (count = 0; rs.next() && count < 5; count++) {
        out.print("<span class=\"date\">\n");
        out.print("<font FACE=\"Arial, Helvetica, sans-serif\">\n");
        out.print(lastModString(rs));
        out.print("</span></font><br>\n");
        out.print("<strong>");

        if (isRedAlert(rs)) {
          out.print("<font color=\"#FF0000\" size=\"-1\">*Alert* </font>");
        }

        out.print(rs.getString("shortdesc"));
        out.print("</strong><br>\n");
        out.print("<font>");
        out.print(rs.getString("longdesc"));

        if (rs.getString("longdesc1") != null) {
          out.print(rs.getString("longdesc1"));
        }

        if (rs.getString("link") != null && 
            !rs.getString("link").trim().equals("")) 
        {
          out.print("&nbsp;&nbsp;<a href=\"");
          out.print(ConvertRoutines.insertHttp(rs.getString("link")));
          out.print("\">More Details</a>");
        }

        out.print("</font><br><br>\n");
      }

      if (count == 0) {
        out.print("no alerts.<br>\n");
      }

      out.print("</body>\n</html>\n");
    } finally {
      out.close();
      ed.close();
    }
  }

  /** Create HTML for the MyUW Community Alerts box, and the Alerts page
    @param args Ignored
   */
  public static void main (String[] args)
  {
    ExtractAlerts ea = new ExtractAlerts();

    try {
      ea.createAlertBox();
      ea.createAlertPage();
    } catch (Exception e) {
      e.printStackTrace(System.err);
      System.exit (1);
    }
  }
}
