// java

package uwcal.out;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.EventsI;
import edu.washington.cac.calendar.data.ItemAccessException;
import edu.washington.cac.calendar.data.NoSuchItemException;
import edu.washington.cac.calendar.data.Sponsor;
import edu.washington.cac.calendar.data.User;

import uwcal.out.forms.CalendarForm;
import uwcal.out.forms.EditSponsorForm;

/**
  Page to edit a sponsor
  @author Greg Barnes
  @version 1.1
 */
public class EditSponsor extends EditEntity 
{
  /** Create a new instance
    @param es user's event cache
    @param message Message to print at top of the page
    @param view View to return to when we're done
    @param s Sponsor to edit.  Should contain the correct id, but need not
      contain other fields

    @exception NoSuchItemException If an event with the matching id does
      not exist
    @exception ItemAccessException If the user cannot edit the event
   */
  EditSponsor(EventsI es, 
              String message, 
              Timeview view,
              Sponsor s) 
      throws NoSuchItemException, ItemAccessException
  {
    super(es, message, view, DisplayText.EDIT_SPONSOR_TITLE, 
          es.getSponsors().getSponsor(s.getId()));
  }

  /**
    Get the form used by this page
    @return the form used by this page
   */
  protected CalendarForm getForm()
  {
    return new EditSponsorForm(this, (Sponsor) this.c);
  }

  /** Return the URL for editing the sponsor.
    @param mc Current date
    @param s Sponsor to edit.
    @param page Page this URL is a part of
    @param sid The session identifier
  */
  public static String url(MyCalendar mc, Sponsor s, Page page, int sid) {
    return EditEntity.url(CalParameter.EDITSPONSOR_FUNC, 
                          Util.SPONSOR_ID_PARAM, mc, page, s, sid);
  }
}
