// java

package uwcal.out;

import org.apache.ecs.Element;
import org.apache.ecs.html.Table;

import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.EventsI;
import edu.washington.cac.calendar.data.User;

import uwcal.out.forms.CalendarForm;

/** 
  An abstract class to create a form involving some entity
  @author Greg Barnes
  @version 1.0
 */
public abstract class EntityPage extends IntermediatePage
{
  /** The title of this page */
  private String title;

  /** Create a new instance
    @param es User's events cache
    @param message Message to print at the top
    @param title Title of the web page
    @param view View to return to when we're done
   */
  EntityPage(EventsI es, 
             String message,
             Timeview view,
             String title)
  {
    super(es, message, view);
    this.title = title;
  }

  /**
    @return A URL that refers to an entity page
    @param function Function to perform
    @param mc date in question
    @param page Page this url is a part of
   */
  protected static String url(String function, MyCalendar mc, Page page) 
  {
    return url(function, mc, page, null);
  }

  /**
    @return A URL that refers to an entity page
    @param function Function to perform
    @param mc date in question
    @param Page page this URL is a part of
    @param prefix Prefix of the URL, instead of the default
   */
  protected static String url(String function, 
                              MyCalendar mc, 
                              Page page,
                              String prefix) 
  {
    return baseUrl(function, prefix) + mc.getDateDigits() + 
           Util.FUNCTION2_PARAM + page.nextFunction();
  }

  /**
    Get the form used by this page
    @return the form used by this page
   */
  protected abstract CalendarForm getForm();

  protected Element contents() 
  {
    return new Table().setBorder(Style.DEFAULT_TABLE_BORDER).
           addElement("\n").addElement(getForm().getForm());
  }

  /** 
    Get the title of the page 
    @return the title of the page 
   */
  protected String title() 
  {
    return this.title;
  }

  /**
    Should this page show the icon legend for guests?
    @return Should this page show the icon legend for guests?
   */
  protected boolean shouldShowIconLegend()
  {
    return false;
  }
}
