// java

package uwcal.out;

import java.sql.SQLException;

import org.apache.ecs.Element;
import org.apache.ecs.ElementContainer;

import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.ItemException;
import edu.washington.cac.calendar.data.Event;
import edu.washington.cac.calendar.data.EventsI;

/** An object that creates a list of events 
  @author Greg Barnes
  @version 1.0
 */
public abstract class EventList 
{
  protected EventPrinter ep;

  protected EventList(EventPrinter ep) 
  { 
    this.ep = ep;
  }

  protected abstract Element eventsRows(Event[] ea, EventsI es);

  /**
    get a list of EventsI for a particular date
    @param date The date in question
    @param es A cache of the events
    @return The list, as HTML
    @exception SQLException If we have to go to the database, and
      there is a problem
    @exception ItemException If we have to go to the database, 
      and it contains bad data
   */
  Element eventsRow(MyCalendar date, EventsI es) 
      throws SQLException, ItemException
  {
    ep.setDate(date);
    return eventsRows(es.oneDaysEvents(date), es);
  }

  /**
    get a list of all appropriate events
    @param es A cache of the events
    @return The list, as HTML
    @exception SQLException If we have to go to the database, and
      there is a problem
    @exception ItemException If we have to go to the database, 
      and it contains bad data
   */
  Element allEvents(EventsI es) throws SQLException, ItemException
  {
    ElementContainer ec = new ElementContainer();

    for (MyCalendar current = ep.getFirstDay(); 
         !ep.getLastDay().isEarlierDay(current); 
         current = current.tomorrow())
    {
      ec.addElement(eventsRow(current, es));
    }

    return ec;
  }
}
