// java

package uwcal.out;

import org.apache.ecs.Element;
import org.apache.ecs.html.Table;

import edu.washington.cac.calendar.CalParameter;
import edu.washington.cac.calendar.MyCalendar;
import edu.washington.cac.calendar.data.Event;
import edu.washington.cac.calendar.data.EventsI;
import edu.washington.cac.calendar.data.NoSuchItemException;
import edu.washington.cac.calendar.data.User;

/**
  A page that shows all the details of an event.
  @author Greg Barnes
  @version 1.1
 */
public class Eventview extends IntermediatePage
{
  private Event e;

  /**
    Create a new instance
    @param es User's events cache
    @param message Message to print at the top of the page
    @param view View to return to when we're done
    @param e Event to display.  Only the id field need be set.
    @exception NoSuchItemException If the event's ID does not exist
   */
  Eventview(EventsI es, 
            String message, 
            Timeview view,
            Event e) 
      throws NoSuchItemException
  {
    super(es, message, view);
    this.e = es.getEvent(e.getId());
  }

  /**
    @return A url that will yield an eventview page 
    @param e Event to view
    @param mc Current date for the page
    @param page Page this URL is a part of
   */
  protected static String url(Event e, MyCalendar mc, Page page) 
  {
    return url(e, mc, page, null);
  }

  /**
    @return A url that will yield an eventview page 
    @param e Event to view
    @param mc Current date for the page
    @param page Page this URL is a part of
    @param prefix URL prefix to use instead of the default
   */
  protected static String url(Event e, 
                              MyCalendar mc, 
                              Page page,
                              String prefix) 
  {
    return baseUrl(CalParameter.EVENTVIEW_FUNC, prefix) + 
        mc.getDateDigits() + Util.FUNCTION2_PARAM + page.nextFunction() +
        Util.EVENT_ID_PARAM + e.getId();
  }

  protected Element contents() 
  {
    return new Table().
        setCellSpacing(20).addElement("\n").
        addElement(new FullEventPrinter(this.user, this.mc, this.es, this.view).
                   format(this.e, this.es)).
        setID(Style.SMALL_BODY_TABLE);
  }

  protected String title() 
  {
    return DisplayText.EVENT_TITLE;
  }

  /**
    Should this page show the icon legend for guests?
    @return Should this page show the icon legend for guests?
   */
  protected boolean shouldShowIconLegend()
  {
    return false;
  }

  /**
    Should this page display the filter message?
    @return Should this view display the filter message?
   */
  protected boolean shouldShowFilterMessage()
  {
    return false;
  }
}
