package uwcal.userlogin;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import edu.washington.cac.myuw.servlet.Log;

import edu.washington.cac.calendar.CalProperties;
import edu.washington.cac.calendar.data.User;

import uwcal.CalLoginServlet;
import uwcal.CalSession;
import uwcal.out.CalMessageMaker;

/**
  User login for the UW Calendar personal display application
  @author Greg Barnes, slh
  @version 1.2
 */
public class CalLogin extends CalLoginServlet
{
  private static final String NAME = "CalUserLogin";

  protected String getName() 
  {
    return NAME;
  }

  /**
    Get the user of the application, or abort if users
    shouldn't log in to this application

    @param req HTTP request object
    @exception IllegalStateException if guests aren't allowed
   */
  protected User getUser(HttpServletRequest req) throws IllegalStateException
  {
    if (CalProperties.defaultIsGuest()) {
      throw new IllegalStateException("No user logins allowed");
    }

    return req.getRemoteUser() == null ? null : new User(req.getRemoteUser());
  }

  protected void startSession(CalSession session,
                              Log log,
                              User user)
      throws Exception
  {
    session.start(user.getNameApp(), log);
  }

  /**
    Send a redirect and print a message to the user saying we're doing so.
    @param req The HttpServletRequest object
    @param resp The HttpServletResponse object
    @param url The url to redirect to
    @exception IOException if there's a problem
   */
  protected void sendRedirect(HttpServletRequest req,
                              HttpServletResponse resp,
                              String url)
      throws IOException
  {
    resp.setHeader("Refresh", "0;URL=" + url);
    new CalMessageMaker().loginMessage(resp, url);
  }

  public String getServletInfo() 
  {
    return "CalLogin servlet: Start Cal Session and redirect";
  }
}
